summaryrefslogtreecommitdiff
path: root/deps/v8/test/mjsunit/wasm/streaming-error-position.js
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/test/mjsunit/wasm/streaming-error-position.js')
-rw-r--r--deps/v8/test/mjsunit/wasm/streaming-error-position.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/deps/v8/test/mjsunit/wasm/streaming-error-position.js b/deps/v8/test/mjsunit/wasm/streaming-error-position.js
index b6d008cd13..77c1b46e85 100644
--- a/deps/v8/test/mjsunit/wasm/streaming-error-position.js
+++ b/deps/v8/test/mjsunit/wasm/streaming-error-position.js
@@ -303,11 +303,11 @@ function testErrorPosition(bytes, pos, test_name) {
1, // functions count
4, // body size
0, // locals count
- kExprGetLocal, 0, // Access a non-existing local
+ kExprLocalGet, 0, // Access a non-existing local
kExprEnd // --
]);
// Find error at the index of kExprGetLocal.
let pos = bytes.length - 1 - 1;
testErrorPosition(bytes, pos, 'testInvalidCode');
})();
@@ -334,7 +334,7 @@ function testErrorPosition(bytes, pos, test_name) {
0, // section length (too big)
]);
// Find error at the index of kExprGetLocal.
let pos = bytes.length - 1;
testErrorPosition(bytes, pos, 'testCodeSectionSizeZero');
})();
@@ -303,11 +303,11 @@ function testErrorPosition(bytes, pos, test_name) {
kExprEnd // --
]);
- // Find error at the index of kExprGetLocal.
+ // Find error at the index of kExprLocalGet.
let pos = bytes.length - 1 - 1;
testErrorPosition(bytes, pos, 'testInvalidCode');
@@ -334,7 +334,7 @@ function testErrorPosition(bytes, pos, test_name) {
0, // section length (too big)
]);
- // Find error at the index of kExprGetLocal.
+ // Find error at the index of kExprLocalGet.
let pos = bytes.length - 1;
testErrorPosition(bytes, pos, 'testCodeSectionSizeZero');